@@ -454,6 +454,9 @@ void filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
 	  }
         }
         switch(getFilterType(method)){
+        case(filter2d::nvalid):
+	  outBuffer[x/down]=stat.nvalid(windowBuffer);
+          break;
         case(filter2d::median):
           if(windowBuffer.empty())
             outBuffer[x/down]=(m_noDataValues.size())? m_noDataValues[0] : 0;
@@ -545,6 +548,18 @@ void filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
 	  outBuffer[x/down]=stat.percentile(windowBuffer,windowBuffer.begin(),windowBuffer.end(),m_threshold[0]);
 	  break;
 	}
+        case(filter2d::proportion):{
+	  if(windowBuffer.size()){
+	    double sum=stat.sum(windowBuffer);
+	    if(sum)
+	      outBuffer[x/down]=100.0*windowBuffer[centre]/stat.sum(windowBuffer);
+	    else
+	      outBuffer[x/down]=(m_noDataValues.size())? m_noDataValues[0] : 0;
+	  }
+	  else
+	    outBuffer[x/down]=(m_noDataValues.size())? m_noDataValues[0] : 0;
+          break;
+	}
         case(filter2d::homog):
 	  if(occurrence.size()==1)//all values in window are the same
 	    outBuffer[x/down]=inBuffer[(dimY-1)/2][x];
