@@ -158,6 +158,7 @@ public:
   template<class T> T sum(const std::vector<T>& v) const;
   template<class T> double mean(const std::vector<T>& v) const;
   template<class T> void eraseNoData(std::vector<T>& v) const;
+  template<class T> unsigned int nvalid(const std::vector<T>& v) const;
   template<class T> T median(const std::vector<T>& v) const;
   template<class T> double var(const std::vector<T>& v) const;
   template<class T> double moment(const std::vector<T>& v, int n) const;
@@ -177,6 +178,8 @@ public:
   template<class T> void normalize(const std::vector<T>& input, std::vector<double>& output) const;
   template<class T> void normalize_pct(std::vector<T>& input) const;
   template<class T> double rmse(const std::vector<T>& x, const std::vector<T>& y) const;
+  template<class T> double nrmse(const std::vector<T>& x, const std::vector<T>& y) const;
+  template<class T> double cvrmse(const std::vector<T>& x, const std::vector<T>& y) const;
   template<class T> double correlation(const std::vector<T>& x, const std::vector<T>& y, int delay=0) const;
   //  template<class T> double gsl_correlation(const std::vector<T>& x, const std::vector<T>& y) const;
   template<class T> double gsl_covariance(const std::vector<T>& x, const std::vector<T>& y) const;
@@ -216,12 +219,17 @@ private:
 template<class T> inline typename std::vector<T>::const_iterator StatFactory::mymin(const std::vector<T>& v, typename std::vector<T>::const_iterator begin, typename std::vector<T>::const_iterator end) const
 {
   bool isValid=false;
-  typename std::vector<T>::const_iterator tmpIt=begin;
+  typename std::vector<T>::const_iterator tmpIt;
   for(typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(!isNoData(*it)){
-      isValid=true;
-      if(*tmpIt>*it)
+      if(isValid){
+	if(*tmpIt>*it)
+	  tmpIt=it;
+      }
+      else{
 	tmpIt=it;
+	isValid=true;
+      }
     }
   }
   if(isValid)
@@ -237,12 +245,17 @@ template<class T> inline typename std::vector<T>::const_iterator StatFactory::my
 template<class T> inline typename std::vector<T>::iterator StatFactory::mymin(const std::vector<T>& v, typename std::vector<T>::iterator begin, typename std::vector<T>::iterator end) const
 {
   bool isValid=false;
-  typename std::vector<T>::iterator tmpIt=begin;
+  typename std::vector<T>::iterator tmpIt;
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(!isNoData(*it)){
-      isValid=true;
-      if(*tmpIt>*it)
+      if(isValid){
+	if(*tmpIt>*it)
+	  tmpIt=it;
+      }
+      else{
 	tmpIt=it;
+	isValid=true;
+      }
     }
   }
   if(isValid)
@@ -258,16 +271,24 @@ template<class T> inline typename std::vector<T>::iterator StatFactory::mymin(co
 template<class T> inline  typename std::vector<T>::const_iterator StatFactory::mymin(const std::vector<T>& v, typename std::vector<T>::const_iterator begin, typename std::vector<T>::const_iterator end, T minConstraint) const
 {
   bool isValid=false;
-  typename std::vector<T>::const_iterator tmpIt=v.end();
+  typename std::vector<T>::const_iterator tmpIt;
   T minValue=minConstraint;
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if((minConstraint<=*it)&&(*it<=minValue)){
+    if(isValid){
+      if((minConstraint<=*it)&&(*it<minValue)){
+	tmpIt=it;
+	minValue=*it;
+      }
+    }
+    else{
+      if(*it<minValue)
+	continue;
       tmpIt=it;
       minValue=*it;
-    }
+      isValid=true;
+    }    
   }
   if(isValid)
     return tmpIt;
@@ -282,16 +303,24 @@ template<class T> inline  typename std::vector<T>::const_iterator StatFactory::m
 template<class T> inline typename std::vector<T>::iterator StatFactory::mymin(const std::vector<T>& v, typename std::vector<T>::iterator begin, typename std::vector<T>::iterator end, T minConstraint) const
 {
   bool isValid=false;
-  typename std::vector<T>::iterator tmpIt=v.end();
+  typename std::vector<T>::iterator tmpIt;
   T minValue=minConstraint;
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if((minConstraint<=*it)&&(*it<=minValue)){
+    if(isValid){
+      if((minConstraint<=*it)&&(*it<minValue)){
+	tmpIt=it;
+	minValue=*it;
+      }
+    }
+    else{
+      if(*it<minConstraint)
+	continue;
       tmpIt=it;
       minValue=*it;
-    }
+      isValid=true;
+    }    
   }
   if(isValid)
     return tmpIt;
@@ -306,13 +335,18 @@ template<class T> inline typename std::vector<T>::iterator StatFactory::mymin(co
 template<class T> inline typename std::vector<T>::const_iterator StatFactory::mymax(const std::vector<T>& v, typename std::vector<T>::const_iterator begin, typename std::vector<T>::const_iterator end) const
 {
   bool isValid=false;
-  typename std::vector<T>::const_iterator tmpIt=begin;
+  typename std::vector<T>::const_iterator tmpIt;
   for (typename std::vector<T>::iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if(*tmpIt<*it)
+    if(isValid){
+      if(*tmpIt<*it)
+	tmpIt=it;
+    }
+    else{
       tmpIt=it;
+      isValid=true;
+    }
   }
   if(isValid)
     return tmpIt;
@@ -327,13 +361,18 @@ template<class T> inline typename std::vector<T>::const_iterator StatFactory::my
 template<class T> inline typename std::vector<T>::iterator StatFactory::mymax(const std::vector<T>& v, typename std::vector<T>::iterator begin, typename std::vector<T>::iterator end) const
 {
   bool isValid=false;
-  typename std::vector<T>::iterator tmpIt=begin;
+  typename std::vector<T>::iterator tmpIt;
   for (typename std::vector<T>::iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if(*tmpIt<*it)
+    if(isValid){
+      if(*tmpIt<*it)
+	tmpIt=it;
+    }
+    else{
       tmpIt=it;
+      isValid=true;
+    }
   }
   if(isValid)
     return tmpIt;
@@ -344,16 +383,24 @@ template<class T> inline typename std::vector<T>::iterator StatFactory::mymax(co
 template<class T> inline typename std::vector<T>::const_iterator StatFactory::mymax(const std::vector<T>& v, typename std::vector<T>::const_iterator begin, typename std::vector<T>::const_iterator end, T maxConstraint) const
 {
   bool isValid=false;
-  typename std::vector<T>::const_iterator tmpIt=v.end();
+  typename std::vector<T>::const_iterator tmpIt;
   T maxValue=maxConstraint;
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if((maxValue<=*it)&&(*it<=maxConstraint)){
+    if(isValid){
+      if((maxConstraint>=*it)&&(*it>maxValue)){
+	tmpIt=it;
+	maxValue=*it;
+      }
+    }
+    else{
+      if(*it>maxConstraint)
+	continue;
       tmpIt=it;
       maxValue=*it;
-    }
+      isValid=true;
+    }    
   }
   if(isValid)
     return tmpIt;
@@ -369,11 +416,19 @@ template<class T> inline typename std::vector<T>::iterator StatFactory::mymax(co
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if((maxValue<=*it)&&(*it<=maxConstraint)){
+    if(isValid){
+      if((maxConstraint>=*it)&&(*it>maxValue)){
+	tmpIt=it;
+	maxValue=*it;
+      }
+    }
+    else{
+      if(*it>maxValue)
+	continue;
       tmpIt=it;
       maxValue=*it;
-    }
+      isValid=true;
+    }    
   }
   if(isValid)
     return tmpIt;
@@ -388,13 +443,18 @@ template<class T> inline T StatFactory::mymin(const std::vector<T>& v) const
     std::string errorString="Error: vector is empty";
     throw(errorString);
   }
-  T minValue=*(v.begin());
+  T minValue;
   for (typename std::vector<T>::const_iterator it = v.begin(); it!=v.end(); ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if(minValue>*it)
+    if(isValid){
+      if(minValue>*it)
       minValue=*it;
+    }
+    else{
+      minValue=*it;
+      isValid=true;
+    }
   }
   if(isValid)
     return minValue;
@@ -413,9 +473,16 @@ template<class T> inline T StatFactory::mymin(const std::vector<T>& v) const
   for (typename std::vector<T>::const_iterator it = v.begin(); it!=v.end(); ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if((minConstraint<=*it)&&(*it<=minValue))
+    if(isValid){
+      if((minConstraint<=*it)&&(*it<minValue))
+	minValue=*it;
+    }
+    else{
+      if(*it<minValue)
+	continue;
       minValue=*it;
+      isValid=true;
+    }    
   }
   if(isValid)
     return minValue;
@@ -434,13 +501,18 @@ template<class T> inline T StatFactory::mymax(const std::vector<T>& v) const
     std::string errorString="Error: vector is empty";
     throw(errorString);
   }
-  T maxValue=*(v.begin());
+  T maxValue;
   for (typename std::vector<T>::const_iterator it = v.begin(); it!=v.end(); ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if(maxValue<*it)
+    if(isValid){
+      if(maxValue<*it)
       maxValue=*it;
+    }
+    else{
+      maxValue=*it;
+      isValid=true;
+    }
   }
   if(isValid)
     return maxValue;
@@ -459,8 +531,16 @@ template<class T> inline T StatFactory::mymax(const std::vector<T>& v, T maxCons
   for (typename std::vector<T>::const_iterator it = v.begin(); it!=v.end(); ++it){
     if(isNoData(*it))
       continue;
-    if((maxValue<=*it)&&(*it<=maxConstraint))
+    if(isValid){
+      if((*it<=maxConstraint)&&(*it>maxValue))
       maxValue=*it;
+    }
+    else{
+      if(*it>maxValue)
+	continue;
+      maxValue=*it;
+      isValid=true;
+    }
   }
   if(isValid)
     return maxValue;
@@ -475,13 +555,18 @@ template<class T> inline T StatFactory::mymax(const std::vector<T>& v, T maxCons
 template<class T> inline typename std::vector<T>::const_iterator StatFactory::absmax(const std::vector<T>& v, typename std::vector<T>::const_iterator begin, typename std::vector<T>::const_iterator end) const
 {
   bool isValid=false;
-  typename std::vector<T>::const_iterator tmpIt=begin;
+  typename std::vector<T>::const_iterator tmpIt;
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if(abs(*tmpIt)<abs(*it))
+    if(isValid){
+      if(abs(*tmpIt)<abs(*it))
+	tmpIt=it;
+    }
+    else{
       tmpIt=it;
+      isValid=true;
+    }
   }
   if(isValid)
     return tmpIt;
@@ -492,13 +577,18 @@ template<class T> inline typename std::vector<T>::const_iterator StatFactory::ab
 template<class T> inline typename std::vector<T>::const_iterator StatFactory::absmin(const std::vector<T>& v, typename std::vector<T>::const_iterator begin, typename std::vector<T>::const_iterator end) const
 {
   bool isValid=false;
-  typename std::vector<T>::const_iterator tmpIt=begin;
+  typename std::vector<T>::const_iterator tmpIt;
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if(abs(*tmpIt)>abs(*it))
+    if(isValid){
+      if(abs(*tmpIt)>abs(*it))
+	tmpIt=it;
+    }
+    else{
       tmpIt=it;
+      isValid=true;
+    }
   }
   if(isValid)
     return tmpIt;
@@ -508,17 +598,36 @@ template<class T> inline typename std::vector<T>::const_iterator StatFactory::ab
 
 template<class T> inline void StatFactory::minmax(const std::vector<T>& v, typename std::vector<T>::const_iterator begin, typename std::vector<T>::const_iterator end, T& theMin, T& theMax) const
 {
+  bool isConstraint=(theMax>theMin);
+  double minConstraint=theMin;
+  double maxConstraint=theMax;
   bool isValid=false;
-  theMin=*begin;
-  theMax=*begin;
   for (typename std::vector<T>::const_iterator it = begin; it!=end; ++it){
     if(isNoData(*it))
       continue;
-    isValid=true;
-    if(theMin>*it)
+    if(isValid){
+      if(isConstraint){
+	if(*it<minConstraint)
+	  continue;
+	if(*it>maxConstraint)
+	  continue;
+      }
+      if(*it<theMin)
+	theMin=*it;
+      if(*it>theMax)
+	theMax=*it;
+    }
+    else{
+      if(isConstraint){
+	if(*it<minConstraint)
+	  continue;
+	if(*it>maxConstraint)
+	  continue;
+      }
       theMin=*it;
-    if(theMax<*it)
       theMax=*it;
+      isValid=true;
+    }
   }
   if(!isValid){
     if(m_noDataValues.size()){
@@ -587,6 +696,12 @@ template<class T> inline void StatFactory::eraseNoData(std::vector<T>& v) const
   }
 }
 
+ template<class T> unsigned int StatFactory::nvalid(const std::vector<T>& v) const{
+  std::vector<T> tmpV=v;
+  eraseNoData(tmpV);
+  return(tmpV.size());
+ }
+
 template<class T> T StatFactory::median(const std::vector<T>& v) const
 {
   std::vector<T> tmpV=v;
@@ -740,11 +855,11 @@ template<class T> void  StatFactory::distribution(const std::vector<T>& input, t
 {
   double minValue=0;
   double maxValue=0;
-  minmax(input,begin,end,minValue,maxValue);
+  minmax(input,begin,end,minimum,maximum);
   if(minimum<maximum&&minimum>minValue)
-    minValue=minimum;
+  minValue=minimum;
   if(minimum<maximum&&maximum<maxValue)
-    maxValue=maximum;
+  maxValue=maximum;
 
   //todo: check...
   minimum=minValue;
@@ -972,6 +1087,7 @@ template<class T> void  StatFactory::percentiles (const std::vector<T>& input, t
     else
       ++vit;
   }
+  eraseNoData(inputSort);
   std::sort(inputSort.begin(),inputSort.end());
   vit=inputSort.begin();
   std::vector<T> inputBin;
@@ -1018,6 +1134,7 @@ template<class T> T  StatFactory::percentile(const std::vector<T>& input, typena
     else
       ++vit;
   }
+  eraseNoData(inputSort);
   std::sort(inputSort.begin(),inputSort.end());
   return gsl_stats_quantile_from_sorted_data(&(inputSort[0]),1,inputSort.size(),percent/100.0);
 }
@@ -1072,6 +1189,60 @@ template<class T> double StatFactory::rmse(const std::vector<T>& x, const std::v
   return sqrt(mse);
 }
 
+//normalized root mean square error
+template<class T> double StatFactory::nrmse(const std::vector<T>& x, const std::vector<T>& y) const{
+  if(x.size()!=y.size()){
+    std::ostringstream s;
+    s<<"Error: x and y not equal in size";
+    throw(s.str());
+  }
+  if(x.empty()){
+    std::ostringstream s;
+    s<<"Error: x is empty";
+    throw(s.str());
+  }
+  std::vector<T> tmpX=x;
+  eraseNoData(tmpX);
+  std::vector<T> tmpY=y;
+  eraseNoData(tmpY);
+  double maxY=mymax(y);
+  double minY=mymin(y);
+  double rangeY=maxY-minY;
+  double mse=0;
+  for(int isample=0;isample<x.size();++isample){
+    double e=x[isample]-y[isample];
+    mse+=e*e/x.size();
+  }
+  return sqrt(mse)/rangeY;
+}
+
+// coefficient of variation root mean square error
+template<class T> double StatFactory::cvrmse(const std::vector<T>& x, const std::vector<T>& y) const{
+  if(x.size()!=y.size()){
+    std::ostringstream s;
+    s<<"Error: x and y not equal in size";
+    throw(s.str());
+  }
+  if(x.empty()){
+    std::ostringstream s;
+    s<<"Error: x is empty";
+    throw(s.str());
+  }
+  std::vector<T> tmpX=x;
+  eraseNoData(tmpX);
+  std::vector<T> tmpY=y;
+  eraseNoData(tmpY);
+  double maxY=mymax(tmpY);
+  double minY=mymin(tmpY);
+  double rangeY=maxY-minY;
+  double mse=0;
+  for(int isample=0;isample<x.size();++isample){
+    double e=x[isample]-y[isample];
+    mse+=e*e/x.size();
+  }
+  return sqrt(mse)/mean(tmpY);
+}
+
 // template<class T> double StatFactory::gsl_correlation(const std::vector<T>& x, const std::vector<T>& y) const{
 //  return(gsl_stats_correlation(&(x[0]),1,&(y[0]),1,x.size()));
 // }
