@@ -25,6 +25,50 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include "imageclasses/ImgReaderOgr.h"
 #include "pkdumpogr.h"
 
+/******************************************************************************/
+/*! \page pkdumpogr pkdumpogr
+ dump ogr file to text file or standard output
+## SYNOPSIS
+
+<code>
+  Usage: pkdumpogr -i input [-o output]
+</code>
+
+<code>
+
+  Options: [-ln layername] [-n attribute]* [-pos] [-transpose]
+
+  Advanced options:
+
+</code>
+
+\section pkdumpogr_description Description
+
+The utility pkdumpogr dumps the content of a vector dataset to (standard) output (screen or filename). The default is to dump all the attributes. Individual attributes can be selected with the option -n. The X and Y positions can be printed with the option -pos. Use the option -transpose to transpose the output (only in combination with the option -n attribute).
+
+\section pkdumpogr_options Options
+ - use either `-short` or `--long` options (both `--long=value` and `--long value` are supported)
+ - short option `-h` shows basic options only, long option `--help` shows all options
+|short|long|type|default|description|
+|-----|----|----|-------|-----------|
+ | i      | input                | std::string |       |Input shape file | 
+ | ln     | lname                | std::string |       |Layer name(s) in sample (leave empty to select all) | 
+ | o      | output               | std::string |       |Output ASCII file | 
+ | n      | name                 | std::string | ALL   |names of the attributes to select. Each attribute is stored in a separate band. Default is ALL: write all attributes | 
+ | pos    | pos                  | bool | false |include position (x and y) | 
+ | t      | transpose            | bool | false |transpose output (does not work for -n ALL  | 
+ | fs     | fs                   | char |       |field separator. | 
+
+Usage: pkdumpogr -i input. [-o output]
+
+
+Examples
+========
+Some examples how to use pkdumpogr can be found \ref examples_pkdumpogr "here"
+**/
+
+using namespace std;
+
 int main(int argc, char *argv[])
 {
   Optionpk<string> input_opt("i", "input", "Input shape file");
@@ -33,8 +77,12 @@ int main(int argc, char *argv[])
   Optionpk<string> attribute_opt("n", "name", "names of the attributes to select. Each attribute is stored in a separate band. Default is ALL: write all attributes", "ALL");
   Optionpk<bool> pos_opt("pos","pos","include position (x and y)",false);
   Optionpk<bool> transpose_opt("t","transpose","transpose output (does not work for -n ALL ",false);
+  Optionpk<char> fs_opt("fs","fs","field separator.",' ');
   Optionpk<short> verbose_opt("v", "verbose", "verbose (Default: 0)", 0,2);
 
+  fs_opt.setHide(1);
+  verbose_opt.setHide(2);
+
   bool doProcess;//stop process when program was invoked with help option (-h --help)
   try{
     doProcess=input_opt.retrieveOption(argc,argv);
@@ -43,6 +91,7 @@ int main(int argc, char *argv[])
     attribute_opt.retrieveOption(argc,argv);
     pos_opt.retrieveOption(argc,argv);
     transpose_opt.retrieveOption(argc,argv);
+    fs_opt.retrieveOption(argc,argv);
     verbose_opt.retrieveOption(argc,argv);
   }
   catch(string predefinedString){
@@ -51,16 +100,20 @@ int main(int argc, char *argv[])
   }
   if(!doProcess){
     cout << endl;
-    cout << "Usage: pkdumpogr -i input.txt [-o output]" << endl;
+    cout << "Usage: pkdumpogr -i input [-o output]" << endl;
     cout << endl;
     std::cout << "short option -h shows basic options only, use long option --help to show all options" << std::endl;
     exit(0);//help was invoked, stop processing
   }
 
-  assert(input_opt.size());
-  ImgReaderOgr imgReader;
+  if(input_opt.empty()){
+    std::cerr << "No input file provided (use option -i). Use --help for help information" << std::endl;
+    exit(0);
+  }
+
+  ImgReaderOgr inputReader;
   try{
-    imgReader.open(input_opt[0]);
+    inputReader.open(input_opt[0]);
   }
   catch(string errorstring){
     cerr << errorstring << endl;
@@ -69,7 +122,7 @@ int main(int argc, char *argv[])
   if(output_opt.size())
     outputFile.open(output_opt[0].c_str(),ios::out);
 
-  ImgReaderOgr inputReader(input_opt[0]);
+  inputReader.setFieldSeparator(fs_opt[0]);
 
   //support multiple layers
   int nlayerRead=inputReader.getDataSource()->GetLayerCount();
@@ -84,10 +137,19 @@ int main(int argc, char *argv[])
 	continue;
     if(verbose_opt[0])
       cout << "processing layer " << currentLayername << endl;
-    if(layer_opt.size())
-      cout << " --lname " << currentLayername;
+    // if(layer_opt.size())
+    //   cout << " --lname " << currentLayername << endl;
       
-    if(attribute_opt[0]!="ALL"){
+    if(attribute_opt[0]=="ALL"){
+      attribute_opt.clear();
+      OGRFeatureDefn *poFDefn = readLayer->GetLayerDefn();
+      for(int iField=0;iField<poFDefn->GetFieldCount();++iField){
+	OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
+	std::string fieldname=poFieldDefn->GetNameRef();
+	attribute_opt.push_back(fieldname);
+      }
+    }
+    // if(attribute_opt[0]!="ALL"){
       vector<double> xvector;
       vector<double> yvector;
       if(inputReader.getGeometryType()==wkbPoint)
@@ -106,37 +168,37 @@ int main(int argc, char *argv[])
       if(transpose_opt[0]){
 	if(pos_opt[0]&&(inputReader.getGeometryType()==wkbPoint)){
 	  if(output_opt.size()){
-	    outputFile << "X" << " ";
+	    outputFile << "X" << fs_opt[0];
 	    for(int isample=0;isample<xvector.size();++isample){
 	      outputFile << xvector[isample];
 	      if(isample<xvector.size()-1)
-		outputFile << " ";
+		outputFile << fs_opt[0];
 	      else
 		outputFile << std::endl;
 	    }
-	    outputFile << "Y" << " ";
+	    outputFile << "Y" << fs_opt[0];
 	    for(int isample=0;isample<yvector.size();++isample){
 	      outputFile << yvector[isample];
 	      if(isample<yvector.size()-1)
-		outputFile << " ";
+		outputFile << fs_opt[0];
 	      else
 		outputFile << std::endl;
 	    }
 	  }
 	  else{
-	    std::cout << "X" << " ";
+	    std::cout << "X" << fs_opt[0];
 	    for(int isample=0;isample<xvector.size();++isample){
 	      std::cout << xvector[isample];
 	      if(isample<xvector.size()-1)
-		std::cout << " ";
+		std::cout << fs_opt[0];
 	      else
 		std::cout << std::endl;
 	    }
-	    std::cout << "Y" << " ";
+	    std::cout << "Y" << fs_opt[0];
 	    for(int isample=0;isample<yvector.size();++isample){
 	      std::cout << yvector[isample];
 	      if(isample<yvector.size()-1)
-		std::cout << " ";
+		std::cout << fs_opt[0];
 	      else
 		std::cout << std::endl;
 	    }
@@ -144,21 +206,21 @@ int main(int argc, char *argv[])
 	}
 	for(int ifield=0;ifield<theData.size();++ifield){
 	  if(output_opt.size()){
-	    outputFile << ifield << " ";
+	    outputFile << ifield << fs_opt[0];
 	    for(int isample=0;isample<theData[0].size();++isample){
 	      outputFile << theData[ifield][isample];
 	      if(isample<theData[0].size()-1)
-		outputFile << " ";
+		outputFile << fs_opt[0];
 	      else
 		outputFile << std::endl;
 	    }
 	  }
 	  else{
-	    std::cout << ifield << " ";
+	    std::cout << ifield << fs_opt[0];
 	    for(int isample=0;isample<theData[0].size();++isample){
 	      std::cout << theData[ifield][isample];
 	      if(isample<theData[0].size()-1)
-		std::cout << " ";
+		std::cout << fs_opt[0];
 	      else
 		std::cout << std::endl;
 	    }
@@ -168,25 +230,25 @@ int main(int argc, char *argv[])
       else{
 	for(int isample=0;isample<theData[0].size();++isample){
 	  if(output_opt.size()){
-	    outputFile << isample << " ";
+	    outputFile << isample << fs_opt[0];
 	    if(pos_opt[0])
-	      outputFile << xvector[isample] << " " << yvector[isample] << " ";
+	      outputFile << xvector[isample] << fs_opt[0] << yvector[isample] << fs_opt[0];
 	    for(int ifield=0;ifield<theData.size();++ifield){
 	      outputFile << theData[ifield][isample];
 	      if(ifield<theData.size()-1)
-		outputFile << " ";
+		outputFile << fs_opt[0];
 	      else
 		outputFile << std::endl;
 	    }
 	  }
 	  else{
-	    std::cout << isample << " ";
+	    std::cout << isample << fs_opt[0];
 	    if(pos_opt[0])
-	      std::cout  << xvector[isample] << " " << yvector[isample] << " ";
+	      std::cout  << xvector[isample] << fs_opt[0] << yvector[isample] << fs_opt[0];
 	    for(int ifield=0;ifield<theData.size();++ifield){
 	      std::cout << theData[ifield][isample];
 	      if(ifield<theData.size()-1)
-		std::cout << " ";
+		std::cout << fs_opt[0];
 	      else
 		std::cout << std::endl;
 	    }
@@ -195,18 +257,17 @@ int main(int argc, char *argv[])
       }
       if(output_opt.size())
 	outputFile.close();
-    }
-    else{
-      if(output_opt.size()){
-	ofstream outputFile(output_opt[0].c_str(),ios::out);
-	outputFile << imgReader;
-	outputFile.close();
-      }
-      else
-	std::cout << imgReader;
-    }
+    // }
+    // else{
+    //   if(output_opt.size()){
+    // 	ofstream outputFile(output_opt[0].c_str(),ios::out);
+    // 	outputFile << inputReader;
+    // 	outputFile.close();
+    //   }
+    //   else
+    // 	std::cout << inputReader;
+    // }
   }
   inputReader.close();
-  imgReader.close();
 }
 
