@@ -90,7 +90,7 @@ percentile | Extract percentile as defined by option perc (e.g, 95th percentile
  | grid   | grid                 | double |       |Create systematic grid of points. Provide cell grid size (in projected units, e.g,. m) | 
  | o      | output               | std::string |       |Output sample dataset | 
  | c      | class                | int  |       |Class(es) to extract from input sample image. Leave empty to extract all valid data pixels from sample dataset. Make sure to set classes if rule is set to mode, proportion or count | 
- | t      | threshold            | float | 100   |Probability threshold for selecting samples (randomly). Provide probability in percentage (>0) or absolute (<0). Use a single threshold for vector sample datasets. If using raster land cover maps as a sample dataset, you can provide a threshold value for each class (e.g. -t 80 -t 60). Use value 100 to select all pixels for selected class(es) | 
+ | t      | threshold            | float | 100   |Probability threshold for selecting samples (randomly). Provide probability in percentage (>0) or absolute (<0). Use a single threshold per vector sample layer. If using raster land cover maps as a sample dataset, you can provide a threshold value for each class (e.g. -t 80 -t 60). Use value 100 to select all pixels for selected class(es) | 
  | perc   | perc                 | double | 95    |Percentile value used for rule percentile | 
  | f      | f                    | std::string | SQLite |Output sample dataset format | 
  | ft     | ftype                | std::string | Real  |Field type (only Real or Integer) | 
@@ -134,7 +134,7 @@ int main(int argc, char *argv[])
   Optionpk<double> grid_opt("grid", "grid", "Create systematic grid of points. Provide cell grid size (in projected units, e.g,. m)");
   Optionpk<string> output_opt("o", "output", "Output sample dataset");
   Optionpk<int> class_opt("c", "class", "Class(es) to extract from input sample image. Leave empty to extract all valid data pixels from sample dataset. Make sure to set classes if rule is set to mode, proportion or count");
-  Optionpk<float> threshold_opt("t", "threshold", "Probability threshold for selecting samples (randomly). Provide probability in percentage (>0) or absolute (<0). Use a single threshold for vector sample datasets. If using raster land cover maps as a sample dataset, you can provide a threshold value for each class (e.g. -t 80 -t 60). Use value 100 to select all pixels for selected class(es)", 100);
+  Optionpk<float> threshold_opt("t", "threshold", "Probability threshold for selecting samples (randomly). Provide probability in percentage (>0) or absolute (<0). Use a single threshold per vector sample layer. If using raster land cover maps as a sample dataset, you can provide a threshold value for each class (e.g. -t 80 -t 60). Use value 100 to select all pixels for selected class(es)", 100);
   Optionpk<double> percentile_opt("perc","perc","Percentile value used for rule percentile",95);
   Optionpk<string> ogrformat_opt("f", "f", "Output sample dataset format","SQLite");
   Optionpk<string> ftype_opt("ft", "ftype", "Field type (only Real or Integer)", "Real");
@@ -857,7 +857,18 @@ int main(int argc, char *argv[])
       std::cout << "creating image sample writer " << output_opt[0] << std::endl;
     ImgWriterOgr ogrWriter;
     ImgWriterOgr ogrTestWriter;
+    double e_ulx;
+    double e_uly;
+    double e_lrx;
+    double e_lry;
     try{
+      sampleReaderOgr.getExtent(e_ulx,e_uly,e_lrx,e_lry);
+      bool hasCoverage=((e_ulx < imgReader.getLrx())&&(e_lrx > imgReader.getUlx())&&(e_lry < imgReader.getUly())&&(e_uly > imgReader.getLry()));
+      if(!hasCoverage){
+	ostringstream ess;
+	ess << "No coverage in " << image_opt[0] << " for any layer in " << sample_opt[0] << endl;
+	throw(ess.str());
+      }
       ogrWriter.open(output_opt[0],ogrformat_opt[0]);
       if(test_opt.size()){
 	if(verbose_opt[0]>1)
@@ -898,15 +909,27 @@ int main(int argc, char *argv[])
     //support multiple layers
     int nlayerRead=sampleReaderOgr.getDataSource()->GetLayerCount();
     int ilayerWrite=0;
+    unsigned long int ntotalvalid=0;
+
     if(verbose_opt[0])
       std::cout << "number of layers: " << nlayerRead << endl;
-      
+
     for(int ilayer=0;ilayer<nlayerRead;++ilayer){
       OGRLayer *readLayer=sampleReaderOgr.getLayer(ilayer);
       string currentLayername=readLayer->GetName();
-      if(layer_opt.size())
-	if(find(layer_opt.begin(),layer_opt.end(),currentLayername)==layer_opt.end())
+      int layerIndex=ilayer;
+      if(layer_opt.size()){
+	vector<string>::const_iterator it=find(layer_opt.begin(),layer_opt.end(),currentLayername);
+	if(it==layer_opt.end())
 	  continue;
+	else
+	  layerIndex=it-layer_opt.begin();
+      }
+      sampleReaderOgr.getExtent(e_ulx,e_uly,e_lrx,e_lry,ilayer);
+      bool hasCoverage=((e_ulx < imgReader.getLrx())&&(e_lrx > imgReader.getUlx())&&(e_lry < imgReader.getUly())&&(e_uly > imgReader.getLry()));
+      if(!hasCoverage)
+	continue;
+      float theThreshold=(threshold_opt.size()==layer_opt.size())? threshold_opt[layerIndex]: threshold_opt[0];
       cout << "processing layer " << currentLayername << endl;
       
       readLayer->ResetReading();
@@ -982,7 +1005,8 @@ int main(int argc, char *argv[])
       }
       OGRFeature *readFeature;
       unsigned long int ifeature=0;
-      unsigned long int nfeature=sampleReaderOgr.getFeatureCount();
+      unsigned long int nfeatureLayer=sampleReaderOgr.getFeatureCount(ilayer);
+      unsigned long int ntotalvalidLayer=0;
       progress=0;
       pfnProgress(progress,pszMessage,pProgressArg);
       while( (readFeature = readLayer->GetNextFeature()) != NULL ){
@@ -990,10 +1014,12 @@ int main(int argc, char *argv[])
 	bool writeTest=false;//write this feature to test_opt[0] instead of output_opt
 	if(verbose_opt[0]>0)
 	  std::cout << "reading feature " << readFeature->GetFID() << std::endl;
-	if(threshold_opt[0]>0){//percentual value
+	if(theThreshold>0){//percentual value
+	  // if(!test_opt.size()&&ntotalvalid>threshold_opt[0]/100.0*nfeature)
+	  //   break;
 	  double p=static_cast<double>(rand())/(RAND_MAX);
 	  p*=100.0;
-	  if(p>threshold_opt[0]){
+	  if(p>theThreshold){
 	    if(test_opt.size())
 	      writeTest=true;
 	    else
@@ -1001,11 +1027,21 @@ int main(int argc, char *argv[])
 	  }
 	}
 	else{//absolute value
-	  if(ntotalvalid>=-threshold_opt[0]){
-	    if(test_opt.size())
-	      writeTest=true;
-	    else
-	      continue;//do not select any more pixels, go to next column feature
+	  if(threshold_opt.size()==layer_opt.size()){
+	    if(ntotalvalidLayer>=-theThreshold){
+	      if(test_opt.size())
+		writeTest=true;
+	      else
+		continue;//do not select any more pixels, go to next column feature
+	    }
+	  }
+	  else{
+	    if(ntotalvalid>=-theThreshold){
+	      if(test_opt.size())
+		writeTest=true;
+	      else
+		continue;//do not select any more pixels, go to next column feature
+	    }
 	  }
 	}
 	if(verbose_opt[0]>0)
@@ -1289,8 +1325,7 @@ int main(int argc, char *argv[])
  		    //destroy feature
 		    OGRFeature::DestroyFeature( writePointFeature );
 		    ++ntotalvalid;
-		    if(verbose_opt[0])
-		      std::cout << "ntotalvalid(2): " << ntotalvalid << std::endl;
+		    ++ntotalvalidLayer;
 		  }
 		}
 	      }
@@ -1517,8 +1552,7 @@ int main(int argc, char *argv[])
 		}
 		OGRFeature::DestroyFeature( writePolygonFeature );
 		++ntotalvalid;
-		if(verbose_opt[0])
-		  std::cout << "ntotalvalid(1): " << ntotalvalid << std::endl;
+		++ntotalvalidLayer;
 	      }
 	      else{
 		if(verbose_opt[0]>1)
@@ -1539,8 +1573,7 @@ int main(int argc, char *argv[])
 		}
 		OGRFeature::DestroyFeature( writeCentroidFeature );
 		++ntotalvalid;
-		if(verbose_opt[0])
-		  std::cout << "ntotalvalid: " << ntotalvalid << std::endl;
+		++ntotalvalidLayer;
 	      }
 	    }
 	  }//if wkbPoint
@@ -1775,8 +1808,7 @@ int main(int argc, char *argv[])
 		    //destroy feature
 		    OGRFeature::DestroyFeature( writePointFeature );
 		    ++ntotalvalid;
-		    if(verbose_opt[0])
-		      std::cout << "ntotalvalid(2): " << ntotalvalid << std::endl;
+		    ++ntotalvalidLayer;
 		  }
 		}
 	      }
@@ -1988,8 +2020,7 @@ int main(int argc, char *argv[])
 		}
 		OGRFeature::DestroyFeature( writePolygonFeature );
 		++ntotalvalid;
-		if(verbose_opt[0])
-		  std::cout << "ntotalvalid(1): " << ntotalvalid << std::endl;
+		++ntotalvalidLayer;
 	      }
 	      else{
 		if(verbose_opt[0]>1)
@@ -2010,8 +2041,7 @@ int main(int argc, char *argv[])
 		}
 		OGRFeature::DestroyFeature( writeCentroidFeature );
 		++ntotalvalid;
-		if(verbose_opt[0])
-		  std::cout << "ntotalvalid: " << ntotalvalid << std::endl;
+		++ntotalvalidLayer;
 	      }
 	    }
 	  }
@@ -2243,8 +2273,7 @@ int main(int argc, char *argv[])
 		  }
 		  // ++isample;
 		  ++ntotalvalid;
-		  if(verbose_opt[0])
-		    std::cout << "ntotalvalid: " << ntotalvalid << std::endl;
+		  ++ntotalvalidLayer;
 	      }
 	    }
 	    if(!validFeature)
@@ -2455,8 +2484,7 @@ int main(int argc, char *argv[])
 		}
 		OGRFeature::DestroyFeature( writePolygonFeature );
 		++ntotalvalid;
-		if(verbose_opt[0])
-		  std::cout << "ntotalvalid: " << ntotalvalid << std::endl;
+		++ntotalvalidLayer;
 	      }
 	      else{
 		if(verbose_opt[0]>1)
@@ -2477,8 +2505,7 @@ int main(int argc, char *argv[])
 		}
 		OGRFeature::DestroyFeature( writeCentroidFeature );
 		++ntotalvalid;
-		if(verbose_opt[0])
-		  std::cout << "ntotalvalid: " << ntotalvalid << std::endl;
+		++ntotalvalidLayer;
 	      }
 	    }
 	  }
@@ -2490,10 +2517,14 @@ int main(int argc, char *argv[])
 	    throw(oss.str());
 	  }
 	  ++ifeature;
-	  if(threshold_opt[0]>0)
-	    progress=(100.0/threshold_opt[0])*static_cast<float>(ifeature+1)/nfeature;
-	  else
-	    progress=static_cast<float>(ifeature+1)/(-threshold_opt[0]);
+	  if(theThreshold>0){
+	    if(threshold_opt.size()==layer_opt.size())
+	      progress=(100.0/theThreshold)*static_cast<float>(ntotalvalidLayer)/nfeatureLayer;
+	    else
+	      progress=static_cast<float>(ntotalvalidLayer)/nfeatureLayer;
+	  }
+ 	  else
+	    progress=static_cast<float>(ifeature+1)/(-theThreshold);
 	  pfnProgress(progress,pszMessage,pProgressArg);
 	}
 	catch(std::string e){
