@@ -56,7 +56,7 @@ The utility pkgetmask creates a mask raster dataset from an input raster dataset
  | b      | band                 | short | 0     |band(s) used for mask | 
  | p      | operator             | std::string | OR    |Operator: [AND,OR]. | 
  | ot     | otype                | std::string | Byte  |Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image | 
- | of     | oformat              | std::string |       |Output image format (see also gdal_translate). Empty string: inherit from input image | 
+ | of     | oformat              | std::string | GTiff |Output image format (see also gdal_translate).| 
  | co     | co                   | std::string |       |Creation option for output file. Multiple options can be specified. | 
  | ct     | ct                   | std::string |       |color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid) | 
 
@@ -79,7 +79,7 @@ int main(int argc,char **argv) {
   Optionpk<unsigned short> nodata_opt("nodata", "nodata", "value(s) for invalid pixels: not between min and max", 0);
   Optionpk<string> output_opt("o", "output", "Output mask file");
   Optionpk<string> otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image", "Byte");
-  Optionpk<string> oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image");
+  Optionpk<string> oformat_opt("of", "oformat", "Output image format (see also gdal_translate).","GTiff");
   Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<string> colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)");
   Optionpk<short> verbose_opt("v", "verbose", "verbose", 0,2);
@@ -187,7 +187,7 @@ int main(int argc,char **argv) {
     if(verbose_opt[0])
       cout << "Using data type from input image: " << GDALGetDataTypeName(theType) << endl;
   }
-  string imageType=imgReader.getImageType();
+  string imageType;//=imgReader.getImageType();
   if(oformat_opt.size())//default
     imageType=oformat_opt[0];
   if(option_opt.findSubstring("INTERLEAVE=")==option_opt.end()){
