@@ -45,18 +45,20 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 
 \section pklas2img_description Description
 
-The utility pklas2img converts a las/laz point cloud into a gridded raster dataset. The implementation is based on <a href="www.liblas.org">liblas</a> API. You can define the bounding box, grid cell size and spatial reference set. The composite rule for multiple returns within a single grid cell can be set with the option -comp. The default attribute is z (heiht), but can also be intensity (if available), the return number (-n return) or the total number of returns in that grid cell (-n nreturn). To select specific returns only, set the option -fir (first, last, single, multiple, or all).
+The utility pklas2img converts a las/laz point cloud into a gridded raster dataset. The implementation is based on <a href="www.liblas.org">liblas</a> API. You can define the bounding box, grid cell size and spatial reference set. The composite rule for multiple returns within a single grid cell can be set with the option -comp. The default attribute is z (heiht), but can also be intensity (if available), scan angle rank (-n angle), the return number (-n return) or the total number of returns in that grid cell (-n nreturn). To select specific returns only, set the option -fir (first, last, single, multiple, or all).
 \section pklas2img_options Options
  - use either `-short` or `--long` options (both `--long=value` and `--long value` are supported)
  - short option `-h` shows basic options only, long option `--help` shows all options
 |short|long|type|default|description|
 |-----|----|----|-------|-----------|
  | i      | input                | std::string |       |Input las file | 
- | n      | name                 | std::string | z     |names of the attribute to select: intensity, return, nreturn, z | 
+ | n      | name                 | std::string | z     |names of the attribute to select: intensity, angle, return, nreturn, z | 
  | ret    | ret                  | unsigned short |       |number(s) of returns to include | 
  | class  | class                | unsigned short |       |classes to keep: 0 (created, never classified), 1 (unclassified), 2 (ground), 3 (low vegetation), 4 (medium vegetation), 5 (high vegetation), 6 (building), 7 (low point, noise), 8 (model key-point), 9 (water), 10 (reserved), 11 (reserved), 12 (overlap) | 
  | comp   | comp                 | std::string | last  |composite for multiple points in cell (min, max, median, mean, sum, first, last, profile (percentile height values), percentile, number (point density)). Last: overwrite cells with latest point | 
  | fir    | filter               | std::string | all   |filter las points (first,last,single,multiple,all). | 
+ | angle_min  | angle_min        | unsigned short |    |minimum scan angle to read points. | 
+ | angle_max  | angle_max        | unsigned short |    |maximum scan angle to read points. | 
  | o      | output               | std::string |       |Output image file | 
  | a_srs  | a_srs                | std::string |       |assign the projection for the output file in epsg code, e.g., epsg:3035 for European LAEA projection | 
  | ulx    | ulx                  | double | 0     |Upper left x value bounding box (in geocoordinates if georef is true). 0 is read from input file | 
@@ -64,7 +66,7 @@ The utility pklas2img converts a las/laz point cloud into a gridded raster datas
  | lrx    | lrx                  | double | 0     |Lower right x value bounding box (in geocoordinates if georef is true). 0 is read from input file | 
  | lry    | lry                  | double | 0     |Lower right y value bounding box (in geocoordinates if georef is true). 0 is read from input file | 
  | ot     | otype                | std::string | Byte  |Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image | 
- | of     | oformat              | std::string | GTiff |Output image format (see also gdal_translate). Empty string: inherit from input image | 
+ | of     | oformat              | std::string | GTiff |Output image format (see also gdal_translate).| 
  | dx     | dx                   | double | 1     |Output resolution in x (in meter) | 
  | dy     | dy                   | double | 1     |Output resolution in y (in meter) | 
  | nbin   | nbin                 | short | 10    |Number of percentile bins for calculating percentile height value profile (=number of output bands) | 
@@ -82,7 +84,7 @@ using namespace std;
 
 int main(int argc,char **argv) {
   Optionpk<string> input_opt("i", "input", "Input las file");
-  Optionpk<string> attribute_opt("n", "name", "names of the point attribute to select: intensity, return, nreturn, z", "z");
+  Optionpk<string> attribute_opt("n", "name", "names of the point attribute to select: intensity, angle, return, nreturn, angle, z", "z");
   // Optionpk<bool> disc_opt("circ", "circular", "circular disc kernel for dilation and erosion", false);
   // Optionpk<double> maxSlope_opt("s", "maxSlope", "Maximum slope used for morphological filtering", 0.0);
   // Optionpk<double> hThreshold_opt("ht", "maxHeight", "initial and maximum height threshold for progressive morphological filtering (e.g., -ht 0.2 -ht 2.5)", 0.2);
@@ -91,6 +93,8 @@ int main(int argc,char **argv) {
   Optionpk<unsigned short> classes_opt("class", "class", "classes to keep: 0 (created, never classified), 1 (unclassified), 2 (ground), 3 (low vegetation), 4 (medium vegetation), 5 (high vegetation), 6 (building), 7 (low point, noise), 8 (model key-point), 9 (water), 10 (reserved), 11 (reserved), 12 (overlap)");
   Optionpk<string> composite_opt("comp", "comp", "composite for multiple points in cell (min, max, median, mean, sum, first, last, profile (percentile height values), percentile, number (point density)). Last: overwrite cells with latest point", "last");
   Optionpk<string> filter_opt("fir", "filter", "filter las points (first,last,single,multiple,all).", "all");
+  Optionpk<unsigned short> angle_min_opt("angle_min", "angle_min", "Minimum scan angle to read points.");
+  Optionpk<unsigned short> angle_max_opt("angle_max", "angle_max", "Maximum scan angle to read points.");
   // Optionpk<string> postFilter_opt("pf", "pfilter", "post processing filter (etew_min,promorph (progressive morphological filter),bunting (adapted promorph),open,close,none).", "none");
   // Optionpk<short> dimx_opt("dimx", "dimx", "Dimension X of postFilter", 3);
   // Optionpk<short> dimy_opt("dimy", "dimy", "Dimension Y of postFilter", 3);
@@ -101,11 +105,11 @@ int main(int argc,char **argv) {
   Optionpk<double> lrx_opt("lrx", "lrx", "Lower right x value bounding box (in geocoordinates if georef is true). 0 is read from input file", 0.0);
   Optionpk<double> lry_opt("lry", "lry", "Lower right y value bounding box (in geocoordinates if georef is true). 0 is read from input file", 0.0);
   Optionpk<string> otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image", "Byte");
-  Optionpk<string> oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image", "GTiff");
+  Optionpk<string> oformat_opt("of", "oformat", "Output image format (see also gdal_translate).", "GTiff");
   Optionpk<double> dx_opt("dx", "dx", "Output resolution in x (in meter)", 1.0);
   Optionpk<double> dy_opt("dy", "dy", "Output resolution in y (in meter)", 1.0);
   Optionpk<short> nbin_opt("nbin", "nbin", "Number of percentile bins for calculating percentile height value profile (=number of output bands)", 10.0);
-  Optionpk<double> percentile_opt("perc","perc","Percentile value used for rule percentile",95);
+  Optionpk<double> percentile_opt("perc","percentile","Percentile value used for rule percentile",95);
   Optionpk<short> nodata_opt("nodata", "nodata", "nodata value to put in image", 0);
   Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<string> colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)");
@@ -125,6 +129,8 @@ int main(int argc,char **argv) {
     classes_opt.retrieveOption(argc,argv);
     composite_opt.retrieveOption(argc,argv);
     filter_opt.retrieveOption(argc,argv);
+    angle_min_opt.retrieveOption(argc,argv);
+    angle_max_opt.retrieveOption(argc,argv);
     output_opt.retrieveOption(argc,argv);
     projection_opt.retrieveOption(argc,argv);
     ulx_opt.retrieveOption(argc,argv);
@@ -249,6 +255,10 @@ int main(int argc,char **argv) {
     std::cout << setprecision(12) << "--ulx=" << minULX << " --uly=" << maxULY << " --lrx=" << maxLRX << " --lry=" << minLRY << std::endl;
     std::cout << "total number of points before filtering: " << totalPoints << std::endl;
     std::cout << "filter set to " << filter_opt[0] << std::endl;
+    if(angle_min_opt.size())
+      std::cout << "minimum scan angle: " << angle_min_opt[0] << std::endl;
+    if(angle_max_opt.size())
+      std::cout << "maximum scan angle: " << angle_max_opt[0] << std::endl;
     // std::cout << "postFilter set to " << postFilter_opt[0] << std::endl;
   }
   int ncol=ceil(maxLRX-minULX)/dx_opt[0];//number of columns in outputGrid
@@ -324,6 +334,11 @@ int main(int argc,char **argv) {
             std::cout << "writing intensity" << std::endl;
           ++ait;
         }
+        if(*ait=="angle"){
+          if(verbose_opt[0])
+            std::cout << "writing angle" << std::endl;
+          ++ait;
+        }
         else if(*ait=="return"){
           if(verbose_opt[0])
             std::cout << "writing return number" << std::endl;
@@ -354,6 +369,14 @@ int main(int argc,char **argv) {
 	continue;
       if((filter_opt[0]=="first")&&(thePoint.GetReturnNumber()!=1))
 	continue;
+      if(angle_min_opt.size()){
+	if(angle_min_opt[0]>thePoint.GetScanAngleRank())
+	  continue;
+      }
+      if(angle_max_opt.size()){
+	if(angle_max_opt[0]<thePoint.GetScanAngleRank())
+	  continue;
+      }
       double dcol,drow;
       outputWriter.geo2image(thePoint.GetX(),thePoint.GetY(),dcol,drow);
       int icol=static_cast<int>(dcol);
@@ -378,6 +401,8 @@ int main(int argc,char **argv) {
         inputData[irow][icol].push_back(thePoint.GetZ());
       else if(attribute_opt[0]=="intensity")
         inputData[irow][icol].push_back(thePoint.GetIntensity());
+      else if(attribute_opt[0]=="angle")
+        inputData[irow][icol].push_back(thePoint.GetScanAngleRank());
       else if(attribute_opt[0]=="return")
         inputData[irow][icol].push_back(thePoint.GetReturnNumber());
       else if(attribute_opt[0]=="nreturn")
