@@ -82,7 +82,8 @@ int main(int argc, char *argv[])
   Optionpk<string> input_opt("i","input","name of the input raster dataset");
   Optionpk<unsigned short> band_opt("b","band","band(s) on which to calculate statistics",0);
   Optionpk<bool>  filename_opt("f", "filename", "Shows image filename ", false);
-  Optionpk<bool>  stat_opt("stats", "statistics", "Shows basic statistics (min,max, mean and stdDev of the raster datasets)", false);
+  Optionpk<bool>  stat_opt("stats", "statistics", "Shows basic statistics (calculate in memory) (min,max, mean and stdDev of the raster datasets)", false);
+  Optionpk<bool>  fstat_opt("fstats", "fstatistics", "Shows basic statistics using GDAL computeStatistics  (min,max, mean and stdDev of the raster datasets)", false);
   Optionpk<double>  ulx_opt("ulx", "ulx", "Upper left x value bounding box");
   Optionpk<double>  uly_opt("uly", "uly", "Upper left y value bounding box");
   Optionpk<double>  lrx_opt("lrx", "lrx", "Lower right x value bounding box");
@@ -119,6 +120,7 @@ int main(int argc, char *argv[])
   Optionpk<bool> regerr_opt("regerr","regerr","calculate linear regression between two raster datasets and get root mean square error",false);
   Optionpk<bool> preg_opt("preg","preg","calculate perpendicular regression between two raster datasets and get correlation coefficient",false);
   Optionpk<short> verbose_opt("v", "verbose", "verbose mode when positive", 0,2);
+  fstat_opt.setHide(1);
   ulx_opt.setHide(1);
   uly_opt.setHide(1);
   lrx_opt.setHide(1);
@@ -142,6 +144,7 @@ int main(int argc, char *argv[])
     band_opt.retrieveOption(argc,argv);
     filename_opt.retrieveOption(argc,argv);
     stat_opt.retrieveOption(argc,argv);
+    fstat_opt.retrieveOption(argc,argv);
     nodata_opt.retrieveOption(argc,argv);
     mean_opt.retrieveOption(argc,argv);
     median_opt.retrieveOption(argc,argv);
@@ -198,9 +201,10 @@ int main(int argc, char *argv[])
   double minY=0;
   double maxX=0;
   double maxY=0;
-  double minValue=0;
-  double maxValue=0;
+  double minValue=(src_min_opt.size())? src_min_opt[0] : 0;
+  double maxValue=(src_max_opt.size())? src_max_opt[0] : 0;
   double meanValue=0;
+  double medianValue=0;
   double stdDev=0;
 
   const char* pszMessage;
@@ -256,23 +260,37 @@ int main(int argc, char *argv[])
       if(scale_opt.size()>ifile)
         imgReader.setScale(scale_opt[ifile],band_opt[iband]);
 
-      // if(stat_opt[0]||mean_opt[0]||var_opt[0]||stdev_opt[0]){
-      // 	assert(band_opt[iband]<imgReader.nrOfBand());
-	// GDALProgressFunc pfnProgress;
-	// void* pProgressData;
-	// GDALRasterBand* rasterBand;
-      // 	rasterBand=imgReader.getRasterBand(band_opt[iband]);
-      // 	rasterBand->ComputeStatistics(0,&minValue,&maxValue,&meanValue,&stdDev,pfnProgress,pProgressData);
+      if(stat_opt[0]||mean_opt[0]||median_opt[0]||var_opt[0]||stdev_opt[0]){//the hard way (in memory)
+	statfactory::StatFactory stat;
+	vector<double> readBuffer;
+	double varValue;
+	imgReader.readDataBlock(readBuffer, GDT_Float64, 0, imgReader.nrOfCol()-1, 0, imgReader.nrOfRow()-1, band_opt[0]);
+	stat.setNoDataValues(nodata_opt);
+	stat.meanVar(readBuffer,meanValue,varValue);
+	medianValue=stat.median(readBuffer);
+	stat.minmax(readBuffer,readBuffer.begin(),readBuffer.end(),minValue,maxValue);
+      	if(mean_opt[0])
+      	  std::cout << "--mean " << meanValue << " ";
+      	if(median_opt[0])
+      	  std::cout << "--median " << medianValue << " ";
+      	if(stdev_opt[0])
+      	  std::cout << "--stdDev " << sqrt(varValue) << " ";
+      	if(var_opt[0])
+      	  std::cout << "--var " << varValue << " ";
+      	if(stat_opt[0])
+      	  std::cout << "-min " << minValue << " -max " << maxValue << " --mean " << meanValue << " --stdDev " << sqrt(varValue) << " ";
+      }
 
-      // 	if(mean_opt[0])
-      // 	  std::cout << "--mean " << meanValue << " ";
-      // 	if(stdev_opt[0])
-      // 	  std::cout << "--stdDev " << stdDev << " ";
-      // 	if(var_opt[0])
-      // 	  std::cout << "--var " << stdDev*stdDev << " ";
-      // 	if(stat_opt[0])
-      // 	  std::cout << "-min " << minValue << " -max " << maxValue << " --mean " << meanValue << " --stdDev " << stdDev << " ";
-      // }
+      if(fstat_opt[0]){//the fast way
+      	assert(band_opt[iband]<imgReader.nrOfBand());
+	GDALProgressFunc pfnProgress;
+	void* pProgressData;
+	GDALRasterBand* rasterBand;
+      	rasterBand=imgReader.getRasterBand(band_opt[iband]);
+      	rasterBand->ComputeStatistics(0,&minValue,&maxValue,&meanValue,&stdDev,pfnProgress,pProgressData);
+
+	std::cout << "-min " << minValue << " -max " << maxValue << " --mean " << meanValue << " --stdDev " << stdDev << " ";
+      }
 
       if(minmax_opt[0]||min_opt[0]||max_opt[0]){
 	assert(band_opt[iband]<imgReader.nrOfBand());
@@ -284,7 +302,7 @@ int main(int argc, char *argv[])
 	  imgReader.getMinMax(static_cast<int>(uli),static_cast<int>(lri),static_cast<int>(ulj),static_cast<int>(lrj),band_opt[iband],minValue,maxValue);
 	}
 	else{
-	  imgReader.getMinMax(minValue,maxValue,band_opt[iband],true);
+	  imgReader.getMinMax(minValue,maxValue,band_opt[iband]);
 	}
 	if(minmax_opt[0])
 	  std::cout << "-min " << minValue << " -max " << maxValue << " ";
@@ -519,12 +537,36 @@ int main(int argc, char *argv[])
     if(rmse_opt[0]&&input_opt.size()<2){
       if(band_opt.size()<2)
 	continue;
-      imgreg.setDown(down_opt[0]);
-      imgreg.setThreshold(random_opt[0]);
-      double c0=0;//offset
-      double c1=1;//scale
-      double err=imgreg.getRMSE(imgReader,band_opt[0],band_opt[1],c0,c1,verbose_opt[0]);
-      std::cout << " -rmse " << err << std::endl;
+      vector<double> xBuffer(imgReader.nrOfCol());
+      vector<double> yBuffer(imgReader.nrOfCol());
+      double mse=0;
+      double nValid=0;
+      double nPixel=imgReader.nrOfCol()/down_opt[0]*imgReader.nrOfRow()/down_opt[0];
+      for(int irow;irow<imgReader.nrOfRow();irow+=down_opt[0]){
+	imgReader.readData(xBuffer,GDT_Float64,irow,band_opt[0]);
+	imgReader.readData(yBuffer,GDT_Float64,irow,band_opt[1]);
+	for(int icol;icol<imgReader.nrOfCol();icol+=down_opt[0]){
+	  double xValue=xBuffer[icol];
+	  double yValue=yBuffer[icol];
+	  if(imgReader.isNoData(xValue)||imgReader.isNoData(yValue)){
+	    continue;
+	  }
+	  if(imgReader.isNoData(xValue)||imgReader.isNoData(yValue)){
+	    continue;
+	  }
+	  if(xValue<src_min_opt[0]||xValue>src_max_opt[0]||yValue<src_min_opt[0]||yValue>src_max_opt[0])
+	    continue;
+	  ++nValid;
+	  double e=xValue-yValue;
+	  if(relative_opt[0])
+	    e/=yValue;
+	  mse+=e*e/nPixel;
+	}
+      }
+      double correctNorm=nValid;
+      correctNorm/=nPixel;
+      mse/=correctNorm;
+      std::cout << " -rmse " << sqrt(mse) << std::endl;
     }
     if(preg_opt[0]&&input_opt.size()<2){
       if(band_opt.size()<2)
@@ -538,6 +580,73 @@ int main(int argc, char *argv[])
     }
     imgReader.close();
   }
+  // if(rmse_opt[0]&&(input_opt.size()>1)){
+  //   while(band_opt.size()<input_opt.size())
+  //     band_opt.push_back(band_opt[0]);
+  //   if(src_min_opt.size()){
+  //     while(src_min_opt.size()<input_opt.size())
+  // 	src_min_opt.push_back(src_min_opt[0]);
+  //   }
+  //   if(src_max_opt.size()){
+  //     while(src_max_opt.size()<input_opt.size())
+  // 	src_max_opt.push_back(src_max_opt[0]);
+  //   }
+  //   ImgReaderGdal imgReader1(input_opt[0]);
+  //   ImgReaderGdal imgReader2(input_opt[1]);
+
+  //   if(offset_opt.size())
+  //     imgReader1.setOffset(offset_opt[0],band_opt[0]);
+  //   if(scale_opt.size())
+  //     imgReader1.setScale(scale_opt[0],band_opt[0]);
+  //   if(offset_opt.size()>1)
+  //     imgReader2.setOffset(offset_opt[1],band_opt[1]);
+  //   if(scale_opt.size()>1)
+  //     imgReader2.setScale(scale_opt[1],band_opt[1]);
+
+  //   for(int inodata=0;inodata<nodata_opt.size();++inodata){
+  //     imgReader1.pushNoDataValue(nodata_opt[inodata]);
+  //     imgReader2.pushNoDataValue(nodata_opt[inodata]);
+  //   }
+  //   vector<double> xBuffer(imgReader1.nrOfCol());
+  //   vector<double> yBuffer(imgReader2.nrOfCol());
+  //   double mse=0;
+  //   double nValid=0;
+  //   double nPixel=imgReader.nrOfCol()/imgReader.nrOfRow()/down_opt[0]/down_opt[0];
+  //   for(int irow;irow<imgReader1.nrOfRow();irow+=down_opt[0]){
+  //     double irow1=irow;
+  //     double irow2=0;
+  //     double icol1=0;
+  //     double icol2=0;
+  //     double geoX=0;
+  //     double geoY=0;
+  //     imgReader1.image2geo(icol1,irow1,geoX,geoY);
+  //     imgReader2.geo2image(geoX,geoY,icol2,irow2);
+  //     irow2=static_cast<int>(irow2);
+  //     imgReader1.readData(xBuffer,GDT_Float64,irow1,band_opt[0]);
+  //     imgReader2.readData(yBuffer,GDT_Float64,irow2,band_opt[1]);
+  //     for(int icol;icol<imgReader.nrOfCol();icol+=down_opt[0]){
+  // 	icol1=icol;
+  // 	imgReader1.image2geo(icol1,irow1,geoX,geoY);
+  // 	imgReader2.geo2image(geoX,geoY,icol2,irow2);
+  // 	double xValue=xBuffer[icol1];
+  // 	double yValue=yBuffer[icol2];
+  // 	if(imgReader.isNoData(xValue)||imgReader.isNoData(yValue)){
+  // 	  continue;
+  // 	}
+  // 	if(xValue<src_min_opt[0]||xValue>src_max_opt[0]||yValue<src_min_opt[1]||yValue>src_max_opt[1])
+  // 	  continue;
+  // 	++nValid;
+  // 	double e=xValue-yValue;
+  // 	if(relative_opt[0])
+  // 	  e/=yValue;
+  // 	mse+=e*e/nPixel;
+  //     }
+  //   }
+  //   double correctNorm=nValid;
+  //   correctNorm/=nPixel;
+  //   mse/=correctNorm;
+  //   std::cout << " -rmse " << sqrt(mse) << std::endl;
+  // }
   if(reg_opt[0]&&(input_opt.size()>1)){
     imgreg.setDown(down_opt[0]);
     imgreg.setThreshold(random_opt[0]);
